@@ -6,31 +6,25 @@
 
 #include "settings.h"
 
-//#include "iostream.hpp"
-
-#include "config.hpp"
 #include "file_util.hpp"
 #include "fstream.hpp"
 #include "errors.hpp"
-#include "string_list.hpp"
 
 #ifdef USE_FILE_LOCKS
-#  include <fcntl.h>
-#  include <unistd.h>
-#  include <sys/types.h>
+ 
+// POSIX headers
+#include <fcntl.h>
+ 
 #endif
-
+ 
+// This needs to be <stdio.h> and not <cstdio>
 #include <stdio.h>
 #include <sys/stat.h>
-#include <dirent.h>
 
 #ifdef WIN32
 
 #  include <io.h>
 #  define ACCESS _access
-#  include <windows.h>
-#  include <winbase.h>
-#  include "asc_ctype.hpp"
 
 #else
 
@@ -42,15 +36,12 @@
 
 namespace acommon {
 
-  // Return false if file is already an absolute path and does not need
-  // a directory prepended.
   bool need_dir(ParmString file) {
-    if (file[0] == '/' || (file[0] == '.' && file[1] == '/')
-#ifdef WIN32
-        || (asc_isalpha(file[0]) && file[1] == ':')
-        || file[0] == '\\' || (file[0] == '.' && file[1] == '\\')
-#endif
-      )
+    if (file[0] == '/' 
+	|| (file[0] == '.' && file[1] == '/')
+	// For Win32:
+	|| (file[0] != '\0' && file[1] == ':')
+	|| (file[0] == '\\'))
       return false;
     else
       return true;
@@ -71,9 +62,9 @@ namespace acommon {
   String figure_out_dir(ParmString dir, ParmString file)
   {
     String temp;
-    int s = file.size() - 1;
+    int s = strlen(file) - 1;
     while (s != -1 && file[s] != '/') --s;
-    if (need_dir(file)) {
+    if (file[0] != '.' && file[0] != '/') {
       temp += dir;
       temp += '/';
     }
@@ -147,6 +138,8 @@ namespace acommon {
 
   bool file_exists(ParmString name) {
     return ACCESS(name, F_OK) == 0;
+    //struct stat fileinfo;
+    //return stat(name, &fileinfo) == 0;
   }
 
   bool rename_file(ParmString orig_name, ParmString new_name)
@@ -166,72 +159,4 @@ namespace acommon {
     }
     return file_name;
   }
-
-  unsigned find_file(const Config * config, const char * option, String & filename)
-  {
-    StringList sl;
-    config->retrieve_list(option, &sl);
-    return find_file(sl, filename);
-  }
-
-  unsigned find_file(const StringList & sl, String & filename)
-  {
-    StringListEnumeration els = sl.elements_obj();
-    const char * dir;
-    String path;
-    while ( (dir = els.next()) != 0 ) 
-    {
-      path = dir;
-      if (path.empty()) continue;
-      if (path.back() != '/') path += '/';
-      unsigned dir_len = path.size();
-      path += filename;
-      if (file_exists(path)) {
-        filename.swap(path);
-        return dir_len;
-      }
-    }
-    return 0;
-  }
-
-  PathBrowser::PathBrowser(const StringList & sl, const char * suf)
-    : dir_handle(0)
-  {
-    els = sl.elements();
-    suffix = suf;
-  }
-
-  PathBrowser::~PathBrowser() 
-  {
-    delete els;
-    if (dir_handle) closedir((DIR *)dir_handle);
-  }
-
-  const char * PathBrowser::next()
-  {
-    if (dir_handle == 0) goto get_next_dir;
-  begin: {
-      struct dirent * entry = readdir((DIR *)dir_handle);
-      if (entry == 0) goto try_again;
-      const char * name = entry->d_name;
-      unsigned name_len = strlen(name);
-      if (suffix.size() != 0 && 
-          !(name_len > suffix.size() 
-            && memcmp(name + name_len - suffix.size(), suffix.str(), suffix.size()) == 0))
-        goto begin;
-      path = dir;
-      if (path.back() != '/') path += '/';
-      path += name;
-    }
-    return path.str();
-  try_again:
-    if (dir_handle) closedir((DIR *)dir_handle);
-    dir_handle = 0;
-  get_next_dir:
-    dir = els->next();
-    if (!dir) return 0;
-    dir_handle = opendir(dir);
-    if (dir_handle == 0) goto try_again;
-    goto begin;
-  }
 }
