@@ -81,6 +81,7 @@ namespace aspeller {
     String   dir_;
     String   name_;
     String   charset_;
+    String   charmap_;
     String   data_encoding_;
 
     ConvObj  mesg_conv_;
@@ -95,7 +96,6 @@ namespace aspeller {
     char          to_upper_[256];
     char          to_title_[256];
     char          to_stripped_[256];
-    unsigned char to_normalized_[256];
     char          to_plain_[256];
     int           to_uni_[256];
     CharType      char_type_[256];
@@ -104,8 +104,6 @@ namespace aspeller {
 
     StoreAs       store_as_;
 
-    int max_normalized_;
-
     String      soundslike_chars_;
     String      clean_chars_;
 
@@ -135,7 +133,7 @@ namespace aspeller {
 
     const char * data_dir() const {return dir_.c_str();}
     const char * name() const {return name_.c_str();}
-    const char * charset() const {return charset_.c_str();}
+    const char * charmap() const {return charmap_.c_str();}
     const char * data_encoding() const {return data_encoding_.c_str();}
 
     const Convert * mesg_conv() const {return mesg_conv_.ptr;}
@@ -176,9 +174,6 @@ namespace aspeller {
     //
     //
 
-    char to_normalized(char c) const {return to_normalized_[to_uchar(c)];}
-    unsigned char max_normalized() const {return max_normalized_;}
-    
     char to_plain(char c) const {return to_plain_[to_uchar(c)];}
 
     char de_accent(char c) const {return de_accent_[to_uchar(c)];}
